@@ -1,7 +1,7 @@
 /* vim: set et ts=8 sw=8: */
 /*
- * Copyright 2014 Red Hat, Inc.
- * Copyright 2015 Ankit (Verma)
+ * Copyright (C) 2014 Red Hat, Inc.
+ * Copyright (C) 2015 Ankit (Verma)
  *
  * Geoclue is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -26,7 +26,7 @@
 #include "gclue-nmea-source.h"
 #include "gclue-location.h"
 #include "config.h"
-#include "gclue-enum-types.h"
+#include "public-api/gclue-enum-types.h"
 
 #include <avahi-client/lookup.h>
 #include <avahi-common/simple-watch.h>
@@ -222,8 +222,7 @@ add_new_service (GClueNMEASource *source,
         g_type_class_unref (enum_class);
 
         if (enum_value == NULL) {
-                g_warning ("Invalid `accuracy` value `%s` inside TXT records.",
-                           value);
+                g_warning ("Invalid `accuracy` value inside TXT records.");
                 accuracy = GCLUE_ACCURACY_LEVEL_EXACT;
 
                 goto CREATE_SERVICE;
@@ -353,11 +352,9 @@ client_callback (AvahiClient     *avahi_client,
 
         g_return_if_fail (avahi_client != NULL);
 
-        priv->avahi_client = avahi_client;
-
         if (state == AVAHI_CLIENT_FAILURE) {
                 const char *errorstr = avahi_strerror
-                        (avahi_client_errno (avahi_client));
+                        (avahi_client_errno (priv->avahi_client));
                 g_warning ("Avahi client failure: %s",
                            errorstr);
         }
@@ -596,8 +593,7 @@ gclue_nmea_source_finalize (GObject *gnmea)
         g_clear_object (&priv->connection);
         g_clear_object (&priv->client);
         g_clear_object (&priv->cancellable);
-        if (priv->avahi_client)
-                avahi_client_free (priv->avahi_client);
+        avahi_client_free (priv->avahi_client);
         g_list_free_full (priv->all_services,
                           avahi_service_free);
 }
@@ -635,11 +631,11 @@ gclue_nmea_source_init (GClueNMEASource *source)
 
         priv->cancellable = g_cancellable_new ();
 
-        avahi_client_new (poll_api,
-                          0,
-                          client_callback,
-                          source,
-                          &error);
+        priv->avahi_client = avahi_client_new (poll_api,
+                                               0,
+                                               client_callback,
+                                               source,
+                                               &error);
 
         if (priv->avahi_client == NULL) {
                 g_warning ("Failed to connect to avahi service: %s",
